==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/english/original_sections/gui/buttons.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	buttons.lang.inc.php 2019-06-07
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	'abort'             => 'Abort',
	'active'            => 'Active',
	'add'               => 'Add',
	'address_change'    => 'Change address',
	'add_to_cart'       => 'Add to cart',
	'view_article'      => 'View article',
	'add_to_wishlist'   => 'Add to wish list',
	'apply'             => 'Apply',
	'back'              => 'Back',
	'back_small'        => 'back',
	'buy_as_guest'      => 'Buy as guest',
	'cancel'            => 'Cancel',
	'canel'             => 'Cancel',
	'checkout'          => 'Checkout',
	'click_here'        => 'Gambio Admin',
	'close'             => 'Close',
	'continue'          => 'Continue',
	'continue_shopping' => 'Continue shopping',
	'create'            => 'Create',
	'delete'            => 'Delete',
	'download'          => 'Download',
	'edit'              => 'Edit',
	'edit_category'     => 'Edit category',
	'edit_content'      => 'Edit content',
	'edit_product'      => 'Edit product',
	'execute'           => 'Execute',
	'go'                => 'Go',
	'inactive'          => 'Inactive',
	'install'           => 'Install',
	'installed'         => 'Installed',
	'login'             => 'Login',
	'new_address'       => 'New address',
	'new_mail'          => 'New Email',
	'next_small'        => 'next',
	'next'              => 'Next',
	'no'                => 'No',
	'ok'                => 'Ok',
	'print'             => 'Print',
	'redeem'            => 'Redeem',
	'refresh'           => 'Refresh',
	'register'          => 'Enter data',
	'save'              => 'Save',
	'search'            => 'Search',
	'send'              => 'Send',
	'send_order'        => 'Order with an obligation to pay',
	'show'              => 'Show',
	'to_cart'           => 'Show cart',
	'to_the_product'    => 'Show product',
	'uninstall'         => 'Uninstall',
	'uninstalled'       => 'Uninstalled',
	'update'            => 'Update',
	'yes'               => 'yes',
	'your_opinion'      => 'Your opinion',
	'forward'           => 'Forward',
	'preview'           => 'Preview',
	'queue'             => 'Queue'
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/english/original_sections/gui/buttons.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	buttons.lang.inc.php 2020-10-06
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	'abort'             => 'Abort',
	'active'            => 'Active',
	'add'               => 'Add',
	'address_change'    => 'Change address',
	'add_to_cart'       => 'Add to cart',
	'view_article'      => 'View article',
	'add_to_wishlist'   => 'Add to wish list',
	'apply'             => 'Apply',
	'back'              => 'Back',
	'back_small'        => 'back',
	'buy_as_guest'      => 'Buy as guest',
	'cancel'            => 'Cancel',
	'canel'             => 'Cancel',
	'checkout'          => 'Checkout',
    'checkout_disabled' => 'Please note minimum/maximum order value.',
	'click_here'        => 'Gambio Admin',
	'close'             => 'Close',
	'continue'          => 'Continue',
	'continue_shopping' => 'Continue shopping',
	'create'            => 'Create',
	'delete'            => 'Delete',
	'download'          => 'Download',
	'edit'              => 'Edit',
	'edit_category'     => 'Edit category',
	'edit_content'      => 'Edit content',
	'edit_product'      => 'Edit product',
	'execute'           => 'Execute',
	'go'                => 'Go',
	'inactive'          => 'Inactive',
	'install'           => 'Install',
	'installed'         => 'Installed',
	'login'             => 'Login',
	'new_address'       => 'New address',
	'new_mail'          => 'New Email',
	'next_small'        => 'next',
	'next'              => 'Next',
	'no'                => 'No',
	'ok'                => 'Ok',
	'print'             => 'Print',
	'redeem'            => 'Redeem',
	'refresh'           => 'Refresh',
	'register'          => 'Enter data',
	'save'              => 'Save',
	'search'            => 'Search',
	'send'              => 'Send',
	'send_order'        => 'Order with an obligation to pay',
	'show'              => 'Show',
	'to_cart'           => 'Show cart',
	'to_the_product'    => 'Show product',
	'uninstall'         => 'Uninstall',
	'uninstalled'       => 'Uninstalled',
	'update'            => 'Update',
	'yes'               => 'yes',
	'your_opinion'      => 'Your opinion',
	'forward'           => 'Forward',
	'preview'           => 'Preview',
	'queue'             => 'Queue',
    'open'              => 'Open'
];
